@@ -478,6 +478,9 @@ class ErrorCodes(object):
         CustomerDefaultPaymentMethodCardTypeIsNotAccepted = "81509"
         CustomerDoesNotHaveCreditCard = "91511"
         CustomerIdIsInvalid = "91510"
+        FailedAuthAdjustmentAllowRetry = "95603"
+        FailedAuthAdjustmentHardDecline = "95602"
+        FinalAuthSubmitForSettlementForDifferentAmount = "95601"
         HasAlreadyBeenRefunded = "91512"
         IdealPaymentNotComplete = "815141"
         IdealPaymentsCannotBeVaulted = "915150"
